@@ -53,9 +53,7 @@ def opreturnOnchainONLY():
             + " https://opreturnbot.com/api/create"
         )
 
-        while True:
-            if len(message) <= 70:
-                break
+        while len(message) > 70:
             clear()
             blogo()
             print("Error! Only 80 characters allowed!")
@@ -155,9 +153,7 @@ def opreturn():
             + " https://opreturnbot.com/api/create"
         )
 
-        while True:
-            if len(message) <= 70:
-                break
+        while len(message) > 70:
             clear()
             blogo()
             print("Error! Only 80 characters allowed!")
@@ -338,6 +334,27 @@ def pgpConn():
 
 #-----------------------------END PGP--------------------------------
 
+#-----------------------------MT--------------------------------
+
+def mtConn():
+    try:
+        conn = """curl -s https://bitcoinexplorer.org/api/price/usd/sats"""
+        a = os.popen(conn).read()
+        clear()
+        blogo()
+        closed()
+        output = render(
+            "Moscow Time", colors=['yellow'], align='left', font='tiny'
+        )
+
+        print(output)
+        print(a)
+        input("\a\nContinue...")
+    except:
+        pass
+
+#-----------------------------END MT--------------------------------
+
 #-----------------------------Satoshi--------------------------------
 
 def satoshiConn():
@@ -363,7 +380,7 @@ def satoshiConn():
 
 def whalalConn():
     try:
-        conn = """curl -s 'https://api.whale-alert.io/v1/transactions?api_key=3LYGErNwoCSj6QUsWOWdpEuGTuYxakMZ&limit=7&currency=btc' | jq  -C '.transactions[]' | tr -d '{|}|,|"|:|' | grep -E "blockchain|amount" -A 8 | grep -v -E "\--|from|symbol|to|id" | xargs -L 1 | sed 's/blockchain/PyBLØCK/g' | sed 's/amount/₿/g' | sed 's/_usd/=$/g' | sed 's/bitcoin/WHALE ALERT/g' | grep -E ' '"""
+        conn = """curl -s 'https://api.whale-alert.io/v1/transactions?api_key=3LYGErNwoCSj6QUsWOWdpEuGTuYxakMZ&limit=7&min_value=5000000&currency=btc' | jq  -C '.transactions[]' | tr -d '{|}|,|"|:|' | grep -E "blockchain|amount" -A 8 | grep -v -E "\--|from|symbol|to|id" | xargs -L 1 | sed 's/blockchain/PyBLØCK/g' | sed 's/amount/₿/g' | sed 's/_usd/=$/g' | sed 's/bitcoin/WHALE ALERT/g' | grep -E ' '"""
         a = os.popen(conn).read()
         clear()
         blogo()
@@ -429,7 +446,7 @@ def quotesConn():
 
 def miningConn():
     try:
-        conn = """curl -s "https://bitcoinexplorer.org/api/mining/hashrate" | jq -C '.[]' | tr -d '{|}|]|,'"""
+        conn = """curl -s "https://bitcoinexplorer.org/api/mining/hashrate" | jq -C '.[]' | tr -d '{|}|]|,' | tr -d '"'"""
         a = os.popen(conn).read()
         clear()
         blogo()
